# Arcaea Offline

> 接受 <i><b>lr</b><sub>lowiro</sub></i> 的一切

![Excel | Eternity](./assets/excel_eternity.png "Excel | Eternity")

## WIP

This project is under active development, thus it is unstable and API may change frequently.

## 这事什么？

这是用于计算 [Arcaea](https://arcaea.lowiro.com/) 中，玩家潜力值的 [B30 和 R10](https://wiki.arcaea.cn/潜力值#整体潜力值计算) 部分的程序。

## 这怎么用？

这个存储库是相对基础的，提供操作数据库等“底层”操作的 python 库。要使用该库，请查阅 API 手册（还没写）。

如果您正寻找 GUI，请前往 [283375/arcaea-offline-pyside-ui](https://github.com/283375/arcaea-offline-pyside-ui) 了解详情。

## Credits

[Arcaea-Infinity/ArcaeaSongDatabase](https://github.com/Arcaea-Infinity/ArcaeaSongDatabase)
